package db

import (
	"github.com/pocketbase/dbx"
	"github.com/pocketbase/pocketbase"
	"htwkalender/model"
	"htwkalender/service/functions"
	"strings"
)

func GetRooms(app *pocketbase.PocketBase) []string {

	var events []struct {
		Rooms string `db:"Rooms" json:"Rooms"`
	}

	// get all rooms from event records in the events collection
	err := app.Dao().DB().Select("Rooms").From("events").All(&events)
	if err != nil {
		print("Error while getting rooms from database: ", err)
		return nil
	}

	var roomArray []string

	for _, event := range events {
		var room = strings.Split(event.Rooms, " ")
		//split functions room by space and add each room to array if it is not already in there
		for _, r := range room {
			var text = strings.TrimSpace(r)
			if !functions.Contains(roomArray, text) && !strings.Contains(text, " ") && len(text) >= 1 {
				roomArray = append(roomArray, text)
			}
		}
	}
	return roomArray
}

func GetRoomScheduleForDay(app *pocketbase.PocketBase, room string, date string) []model.Event {
	var events []model.Event

	// get all events from event records in the events collection
	err := app.Dao().DB().Select("*").From("events").Where(dbx.Like("Rooms", room)).AndWhere(dbx.Like("Start", date)).All(&events)
	if err != nil {
		print("Error while getting events from database: ", err)
		return nil
	}
	return events
}
